@@ -11,8 +11,6 @@
 #' the log2 ratio values.
 #' Finally, a visualization tool is provided to explore resulting metrics.
 #'
-#' @docType package
-#'
 #' @name CNVMetrics-package
 #'
 #' @aliases CNVMetrics-package CNVMetrics
@@ -25,14 +23,15 @@
 #'
 #' @seealso
 #' \itemize{
-#'     \item \code{\link{calculateOverlapMetric}} {for calculating metric
+#'     \item{\code{\link{calculateOverlapMetric}} for calculating metric
 #'     using overlapping amplified/deleted regions}
-#'     \item \code{\link{calculateLog2ratioMetric}} {for calculating metric
+#'     \item{\code{\link{calculateLog2ratioMetric}} for calculating metric
 #'     using log2ratio values}
-#'     \item \code{\link{processSim}} {for generating simulations}
-#'     \item \code{\link{plotMetric}} {for plotting metrics}
+#'     \item{\code{\link{processSim}} for generating simulations}
+#'     \item{\code{\link{plotMetric}} for plotting metrics}
 #' }
 #'
 #' @encoding UTF-8
 #' @keywords package
-NULL
+"_PACKAGE"
+
